"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const postcss_1 = tslib_1.__importDefault(require("postcss"));
const postcss_load_config_1 = tslib_1.__importDefault(require("postcss-load-config"));
const postcss_modules_values_1 = tslib_1.__importDefault(require("postcss-modules-values"));
const postcss_modules_local_by_default_1 = tslib_1.__importDefault(require("postcss-modules-local-by-default"));
const postcss_modules_scope_1 = tslib_1.__importDefault(require("postcss-modules-scope"));
const icss_utils_1 = require("icss-utils");
const camelcase_1 = tslib_1.__importDefault(require("camelcase"));
const sync_1 = tslib_1.__importDefault(require("./sync"));
class Parser {
    constructor(settings) {
        this.settings = settings;
        const { plugins, options } = this.loadConfig();
        this.processor = postcss_1.default(plugins);
        this.postcssOptions = options;
        this.processor
            .use(postcss_modules_values_1.default)
            .use(postcss_modules_local_by_default_1.default({ mode: this.settings.defaultScope }))
            .use(postcss_modules_scope_1.default({
            generateScopedName: name => name,
        }));
    }
    parse(filename) {
        const css = fs_1.default.readFileSync(filename);
        const options = { ...this.postcssOptions, from: filename };
        const { root } = sync_1.default(this.processor.process(css, options));
        if (root) {
            const { icssExports } = icss_utils_1.extractICSS(root, false);
            const classNames = this.convertClassNames(Object.keys(icssExports));
            return new Set(classNames);
        }
        return new Set();
    }
    loadConfig() {
        try {
            const { plugins, options } = postcss_load_config_1.default.sync({}, this.settings.postcssConfigDir);
            options.map = false;
            options.stringifier = () => { };
            return { plugins, options };
        }
        catch (err) {
            return { plugins: [], options: { stringifier: () => { }, map: false } };
        }
    }
    convertClassNames(classNames) {
        if (this.settings.camelCase === false ||
            this.settings.camelCase === "asIs") {
            return classNames;
        }
        const camelCaseClassNames = this.settings.camelCase === true ||
            this.settings.camelCase === "camelCase" ||
            this.settings.camelCase === "camelCaseOnly" ||
            this.settings.camelCase === "only"
            ? classNames.map(cn => camelcase_1.default(cn))
            : classNames.map(this.convertDashesToCamelCase);
        if (this.settings.camelCase === "camelCaseOnly" ||
            this.settings.camelCase === "dashesOnly" ||
            this.settings.camelCase === "only") {
            return camelCaseClassNames;
        }
        return classNames.concat(camelCaseClassNames);
    }
    convertDashesToCamelCase(className) {
        return className.replace(/-+(\w)/g, (_, firstLetter) => firstLetter.toUpperCase());
    }
}
exports.default = Parser;
