import { Rule } from "eslint";
import * as ESTree from "estree";
export declare const nodeIsImportDeclaration: (node: ESTree.Node) => node is ESTree.ImportDeclaration;
export declare const nodeIsImportSpecifier: (node: ESTree.Node) => node is ESTree.ImportSpecifier;
export declare const nodeIsImportDefaultSpecifier: (node: ESTree.Node) => node is ESTree.ImportDefaultSpecifier;
export declare const nodeIsImportNamespaceSpecifier: (node: ESTree.Node) => node is ESTree.ImportNamespaceSpecifier;
export declare const nodeIsMemberExpression: (node: ESTree.Node) => node is ESTree.MemberExpression;
export interface BaseFilenameToClasses {
    [key: string]: {
        node: ESTree.Node;
        classes: ReadonlySet<string>;
    };
}
export interface SpecifierToClasses {
    [key: string]: {
        baseFilename: string;
        classes: ReadonlySet<string>;
    };
}
export interface ProcessedImportDeclaration {
    node: ESTree.ImportDeclaration;
    baseFilename: string;
    specifier: string | null;
    explicitImports: ESTree.ImportSpecifier[];
    classes: ReadonlySet<string>;
}
export interface ProcessedMemberExpression {
    node: ESTree.MemberExpression;
    baseFilename: string;
    className: string;
    classes: ReadonlySet<string>;
}
export declare class Cache {
    private static baseFilenameToClasses;
    private static specifierToClasses;
    private settings;
    private parser;
    constructor(context: Rule.RuleContext);
    static clear(): void;
    processImportDeclaration(node: ESTree.Node): ProcessedImportDeclaration | null;
    processMemberExpression(node: ESTree.Node): ProcessedMemberExpression | null;
}
